<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\AdminsRequest;
use App\Http\Requests\Admin\ClientsRequest;
use App\Models\City;
use App\Models\User;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;

class ClientsController extends Controller
{


    public function index()
    {
        $rows = User::whereType('client')->get();

        return view('admin.clients.index', compact('rows'));
    }

    public function create()
    {
        $cities = City::all();
        return view('admin.clients.create', compact('cities'));
    }

    public function store(ClientsRequest $request)
    {
        $client = new User();
        $client->email = $request['email'];
        $client->type = 'client';
        $client->name = $request['name'];
        $client->mobile = $request['mobile'];
        $client->city_id = $request['city_id'];
        $client->password = bcrypt($request['password']);
        $client->status = $request['status'];
        if ($request->hasFile('profile_image')) {
            $filename = time() . '.' . $request['profile_image']->getClientOriginalExtension();
            $request['profile_image']->move(public_path('images/users'), $filename);
            $client->profile_image = $filename;
        }
        $client->save();
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('clients.index');
    }

    public function edit($id)
    {
        $row = User::findOrFail($id);
        $cities = City::all();

        return view('admin.clients.edit', compact('row', 'cities'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'email' => 'required|max:191|email|unique:users,email,' . $id,
            'name' => 'required|max:191',
            'password' => 'nullable|min:6|max:191',
            'mobile' => 'required|unique:users,mobile,' . $id,
            'city_id' => 'required'
        ]);
        $client = User::findOrFail($id);
        $client->email = $request['email'];
        $client->type = 'client';
        $client->name = $request['name'];
        $client->mobile = $request['mobile'];
        $client->city_id = $request['city_id'];
        if ($request->password)  $client->password = bcrypt($request['password']);
        $client->status = $request['status'];
        if ($request->hasFile('profile_image')) {
            $filename = time() . '.' . $request['profile_image']->getClientOriginalExtension();
            $request['profile_image']->move(public_path('images/users'), $filename);
            $client->profile_image = $filename;
        }
        $client->update();
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('clients.index');
    }

    public function destroy($id)
    {

        User::destroy($id);
        toast('تمت العملية بنجاح', 'success');
        return back();

    }
}
