<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;
use Tymon\JWTAuth\Contracts\JWTSubject;

class User extends Authenticatable implements JWTSubject
{
    use HasApiTokens, HasFactory, Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var string[]
     */
    protected $fillable = [
        'name',
        'email',
        'password',
        'mobile',
        'city_id',
        'category_id',
        'subscription_id',
        'type',
        'verification_status',
        'verification_code',
        'status',
        'profile_image',
        'end_subscription',
        'admin_approve'
    ];
    protected $appends = ['in_subscribe'];

    public function getInSubscribeAttribute()
    {
        //        if (Carbon::now() > Carbon::parse($user->end_subscription)){
//            return  response()->json(['value'=>false,'msg'=>\Lang::get('data.subscriptionEnded')]);
//        }

        $in_subscribe = false;

        if ($this->subscription_id == null || $this->end_subscription == null) {
            $in_subscribe = false;
        } elseif (Carbon::now() > Carbon::parse($this->end_subscription)) {
            $in_subscribe = false;

        } else {
            $in_subscribe = true;
        }
        return $in_subscribe;

    }

    public function city()
    {
        return $this->belongsTo(City::class, 'city_id');
    }

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public function getJWTIdentifier()
    {
        return $this->getKey();
    }

    public function getJWTCustomClaims()
    {
        return [];
    }

    public function favourites()
    {
        return $this->belongsToMany(Service::class, 'favourites', 'user_id', 'service_id');
    }


    public function category()
    {
        return $this->belongsTo(Category::class, 'category_id');
    }

    public function subscription()
    {
        return $this->belongsTo(Package::class, 'subscription_id');
    }


}
